@@ -21,10 +21,17 @@ setGeneric("predict", function(object, ...)
 #' @return A vector with the predicted values.
 #'
 #' @author Sergio Vignali
-setMethod("predict",
-          signature = "BRT",
-          definition = function(object, data, type, clamp) {
-            output <- predict(object@model, newdata = data,
-                              n.trees = object@n.trees, type = "response")
-            return(output)
-          })
+setMethod(
+  f = "predict",
+  signature = "BRT",
+  definition = function(object,
+                        data,
+                        type,
+                        clamp) {
+
+    predict(object@model,
+            newdata = data,
+            n.trees = object@n.trees,
+            type = "response")
+  }
+)
