@@ -32,14 +32,10 @@ test_that("The function raises errors", {
                                filename = "spam"))
 })
 
-test_that("The function warns", {
-  expect_snapshot_warning(plotPA(map,
-                                 th = .8,
-                                 format = "GTiff"))
-
+test_that("The function warns and raises errors", {
   # TODO: Remove with version 2.0.0
-  expect_snapshot_warning(plotPA(raster::raster(matrix(runif(400, 0, 1),
-                                                       nrow = 20,
-                                                       ncol = 20)),
-                                 th = .8))
+  x <- integer(1)
+  class(x) <- "Raster"
+  expect_snapshot_error(plotPA(x,
+                        th = .8))
 })
