@@ -70,9 +70,10 @@ test_that("The function raises errors", {
 })
 
 # TODO: Remove with version 2.0.0
-test_that("The function warns if a raster object is used", {
-  env <- raster::stack(files)
-  expect_snapshot_warning(
-    prepareSWD(species = "Bgs", a = a, env = env, verbose = FALSE)
-  )
+test_that("The function raises an error if a raster object is used", {
+  class(env) <- "Raster"
+  expect_snapshot_error(prepareSWD(species = "Bgs",
+                                   a = a,
+                                   env = env,
+                                   verbose = FALSE))
 })
